Struct byte_aes::decrypt::Decryptor

source ·
pub struct Decryptor { /* private fields */ }
Initialize the Struct with the encypted bytes Vec<u8> using the from() method and perform decryption operations

Implementations

source

impl Decryptor

source

pub fn decrypt_with(&mut self, key: &String) -> Vec<u8>

Takes a Key of 32 bytes in length to Decrypt the text initialized with the Decryptor::from() associated function

Examples
use byte_aes::encrypt::Encryptor;
use byte_aes::decrypt::Decryptor;
 
let my_32byte_key = "Thisi$MyKeyT0Encryp!thislastTime".to_owned();
let original_text = "I am Omkaram Venkatesh and this is my plain text and some random chars 223@#$^$%*%^(!#@%$~@#$[]]'///\\drewe. Lets see if this gets encrypted now)".to_string();
let original_bytes = original_text.as_bytes();
 
let mut encrypt_obj: Encryptor = Encryptor::from(original_text.as_str());
let encrypted_bytes: Vec<u8> = encrypt_obj.encrypt_with(&my_32byte_key);
 
//encrypted_bytes is borrowed here
let mut decrypted_obj: Decryptor = Decryptor::from(encrypted_bytes.as_ref());
let decrypted_bytes: Vec<u8>  = decrypted_obj.decrypt_with(&my_32byte_key);
let decrypted_text: String = String::from_utf8_lossy(&decrypted_bytes).to_string();
 
assert_eq!(original_text, decrypted_text);
 
//encrypted_bytes is moved here
let mut decrypted_obj: Decryptor = Decryptor::from(encrypted_bytes);
let decrypted_bytes: Vec<u8> = decrypted_obj.decrypt_with(&my_32byte_key);
 
assert_eq!(original_bytes, decrypted_bytes);
 

The output from the variable ‘decrypted_text’ would return your orginal text