pub trait OMFE {
// Required method
fn get_raw_bytes(&self) -> Vec<u8>;
}Expand description
I have no idea why you would need this trait for public use, but here you go
pub trait OMFE {
// Required method
fn get_raw_bytes(&self) -> Vec<u8>;
}I have no idea why you would need this trait for public use, but here you go