Byte-AES
Developer: Omkarium
byte-aes is a simple wrapper around the popular aes crate. The goal is to perform Encrypt and Decrypt operations
using the Advanced Encryption Standard 256 bit Algorithm conveninent to use instead of use Low level functions of the aes crate
Re-exports
Modules
Traits
- I have no idea why you would need this trait for public use, but here you go