Struct byte_aes::encrypt::Encryptor

source ·
pub struct Encryptor { /* private fields */ }
Initialize the Struct with text as String type using the from() method and perform encryption operations

Implementations

source

impl Encryptor

source

pub fn encrypt_with(&mut self, key: &String) -> Vec<u8>

Takes a Key of 32 bytes in length to Encrypt the text initialized with the Encryptor::from() associated function

Examples
use byte_aes::encrypt::Encryptor;
 
let my_32byte_key = "Thisi$MyKeyT0Encryp!thislastTime".to_owned();
let original_text = "I am Omkaram Venkatesh and this is my plain text and some random chars 223@#$^$%*%^(!#@%$~@#$[]]'///\\drewe. Lets see if this gets encrypted now)".to_string();
 
let mut encrypt_obj: Encryptor = Encryptor::from(&original_text);
let encrypted_bytes: Vec<u8> = encrypt_obj.encrypt_with(&my_32byte_key);

The output from the variable ‘encrypted_bytes’ would return a Vec<u8>